@@ -249,16 +249,16 @@ def get_dict(m, prefix=None, for_env=True, skip_build_id=False):
     d = conda_build_vars(prefix, m.config)
 
     # languages
-    d.update(python_vars(m))
-    d.update(perl_vars(m))
-    d.update(lua_vars(m))
-    d.update(r_vars(m))
+    d.update(python_vars(m, prefix))
+    d.update(perl_vars(m, prefix))
+    d.update(lua_vars(m, prefix))
+    d.update(r_vars(m, prefix))
 
     if m:
         d.update(meta_vars(m, skip_build_id=skip_build_id))
 
     # system
-    d.update(system_vars(d, m))
+    d.update(system_vars(d, m, prefix))
 
     # features
     d.update({feat.upper(): str(int(value)) for feat, value in
@@ -301,22 +301,21 @@ def conda_build_vars(prefix, config):
     }
 
 
-def python_vars(metadata):
+def python_vars(metadata, prefix):
     py_ver = get_py_ver(metadata.config)
     vars_ = {
             'CONDA_PY': ''.join(py_ver.split('.')[:2]),
             'PY3K': str(int(int(py_ver[0]) >= 3)),
             'PY_VER': py_ver,
-            'STDLIB_DIR': utils.get_stdlib_dir(metadata.config.host_prefix, py_ver),
-            'SP_DIR': utils.get_site_packages(metadata.config.host_prefix, py_ver),
+            'STDLIB_DIR': utils.get_stdlib_dir(prefix, py_ver),
+            'SP_DIR': utils.get_site_packages(prefix, py_ver),
             }
     build_or_host = 'host' if metadata.is_cross else 'build'
     deps = [str(ms.name) for ms in metadata.ms_depends(build_or_host)]
-    if 'python' in deps:
+    if 'python' in deps or metadata.name(fail_ok=True) == 'python':
         vars_.update({
             # host prefix is always fine, because it is the same as build when is_cross is False
-            'PYTHON': metadata.config.python_bin(metadata.config.host_prefix,
-                                                 metadata.config.host_subdir),
+            'PYTHON': metadata.config.python_bin(prefix, metadata.config.host_subdir),
         })
 
     np_ver = metadata.config.variant.get('numpy', get_default_variant(metadata.config)['numpy'])
@@ -325,23 +324,22 @@ def python_vars(metadata):
     return vars_
 
 
-def perl_vars(metadata):
+def perl_vars(metadata, prefix):
     vars_ = {
             'PERL_VER': get_perl_ver(metadata.config),
             'CONDA_PERL': get_perl_ver(metadata.config),
              }
     build_or_host = 'host' if metadata.is_cross else 'build'
     deps = [str(ms.name) for ms in metadata.ms_depends(build_or_host)]
-    if 'perl' in deps:
+    if 'perl' in deps or metadata.name(fail_ok=True) == 'perl':
         vars_.update({
             # host prefix is always fine, because it is the same as build when is_cross is False
-            'PERL': metadata.config.perl_bin(metadata.config.host_prefix,
-                                             metadata.config.host_subdir),
+            'PERL': metadata.config.perl_bin(prefix, metadata.config.host_subdir),
         })
     return vars_
 
 
-def lua_vars(metadata):
+def lua_vars(metadata, prefix):
     vars_ = {
             'LUA_VER': get_lua_ver(metadata.config),
             'CONDA_LUA': get_lua_ver(metadata.config),
@@ -350,14 +348,14 @@ def lua_vars(metadata):
     deps = [str(ms.name) for ms in metadata.ms_depends(build_or_host)]
     if 'lua' in deps:
         vars_.update({
-            'LUA': metadata.config.lua_bin(metadata.config.host_prefix,
+            'LUA': metadata.config.lua_bin(prefix,
                                            metadata.config.host_subdir),
             'LUA_INCLUDE_DIR': get_lua_include_dir(metadata.config),
         })
     return vars_
 
 
-def r_vars(metadata):
+def r_vars(metadata, prefix):
     vars_ = {
             'R_VER': get_r_ver(metadata.config),
             'CONDA_R': get_r_ver(metadata.config),
@@ -365,10 +363,10 @@ def r_vars(metadata):
 
     build_or_host = 'host' if metadata.is_cross else 'build'
     deps = [str(ms.name) for ms in metadata.ms_depends(build_or_host)]
-    if 'r-base' in deps or 'mro-base' in deps:
+    if 'r-base' in deps or 'mro-base' in deps or metadata.name(fail_ok=True) in (
+            'r-base', 'mro-base'):
         vars_.update({
-            'R': metadata.config.r_bin(metadata.config.host_prefix,
-                                       metadata.config.host_subdir),
+            'R': metadata.config.r_bin(prefix, metadata.config.host_subdir),
         })
     return vars_
 
@@ -469,14 +467,14 @@ def get_shlib_ext():
         raise NotImplementedError(sys.platform)
 
 
-def windows_vars(m, get_default):
+def windows_vars(m, get_default, prefix):
     """This is setting variables on a dict that is part of the get_default function"""
     # We have gone for the clang values here.
     win_arch = 'i386' if str(m.config.host_arch) == '32' else 'amd64'
     win_msvc = '19.0.0' if PY3 else '15.0.0'
-    library_prefix = join(m.config.host_prefix, 'Library')
+    library_prefix = join(prefix, 'Library')
     drive, tail = m.config.host_prefix.split(':')
-    get_default('SCRIPTS', join(m.config.host_prefix, 'Scripts'))
+    get_default('SCRIPTS', join(prefix, 'Scripts'))
     get_default('LIBRARY_PREFIX', library_prefix)
     get_default('LIBRARY_BIN', join(library_prefix, 'bin'))
     get_default('LIBRARY_INC', join(library_prefix, 'include'))
@@ -521,15 +519,15 @@ def windows_vars(m, get_default):
             get_default(env_var)
 
 
-def unix_vars(m, get_default):
+def unix_vars(m, get_default, prefix):
     """This is setting variables on a dict that is part of the get_default function"""
     get_default('HOME', 'UNKNOWN')
-    get_default('PKG_CONFIG_PATH', join(m.config.host_prefix, 'lib', 'pkgconfig'))
+    get_default('PKG_CONFIG_PATH', join(prefix, 'lib', 'pkgconfig'))
     get_default('CMAKE_GENERATOR', 'Unix Makefiles')
     get_default('SSL_CERT_FILE')
 
 
-def osx_vars(m, get_default):
+def osx_vars(m, get_default, prefix):
     """This is setting variables on a dict that is part of the get_default function"""
     OSX_ARCH = 'i386' if str(m.config.host_arch) == '32' else 'x86_64'
     # 10.7 install_name_tool -delete_rpath causes broken dylibs, I will revisit this ASAP.
@@ -540,12 +538,18 @@ def osx_vars(m, get_default):
     get_default('BUILD', OSX_ARCH + '-apple-darwin13.4.0')
 
 
-def linux_vars(m, get_default):
+@memoized
+def _machine_and_architecture():
+    return platform.machine(), platform.architecture()
+
+
+def linux_vars(m, get_default, prefix):
     """This is setting variables on a dict that is part of the get_default function"""
-    build_arch = platform.machine()
+    platform_machine, platform_architecture = _machine_and_architecture()
+    build_arch = platform_machine
     # Python reports x86_64 when running a i686 Python binary on a 64-bit CPU
     # unless run through linux32. Issue a warning when we detect this.
-    if build_arch == 'x86_64' and platform.architecture()[0] == '32bit':
+    if build_arch == 'x86_64' and platform_architecture[0] == '32bit':
         print("Warning: You are running 32-bit Python on a 64-bit linux installation")
         print("         but have not launched it via linux32. Various qeuries *will*")
         print("         give unexpected results (uname -m, platform.machine() etc)")
@@ -568,7 +572,7 @@ def linux_vars(m, get_default):
     get_default('QEMU_UNAME')
     get_default('DEJAGNU')
     get_default('DISPLAY')
-    get_default('LD_RUN_PATH', m.config.host_prefix + '/lib')
+    get_default('LD_RUN_PATH', prefix + '/lib')
     get_default('BUILD', build_arch + '-conda_' + build_distro + '-linux-gnu')
 
 
@@ -581,7 +585,7 @@ def set_from_os_or_variant(out_dict, key, variant, default):
 
 
 @memoized
-def system_vars(env_dict, m):
+def system_vars(env_dict, m, prefix):
     d = dict()
     # note the dictionary is passed in here - variables are set in that dict if they are non-null
     get_default = lambda key, default='': set_from_os_or_variant(d, key, m.config.variant, default)
@@ -597,14 +601,14 @@ def system_vars(env_dict, m):
         d = prepend_bin_path(d, m.config.host_prefix)
 
     if sys.platform == 'win32':
-        windows_vars(m, get_default)
+        windows_vars(m, get_default, prefix)
     else:
-        unix_vars(m, get_default)
+        unix_vars(m, get_default, prefix)
 
     if sys.platform == 'darwin':
-        osx_vars(m, get_default)
+        osx_vars(m, get_default, prefix)
     elif sys.platform.startswith('linux'):
-        linux_vars(m, get_default)
+        linux_vars(m, get_default, prefix)
 
     return d
 
