@@ -1,6 +1,7 @@
 from __future__ import absolute_import, division, print_function
 
 from collections import OrderedDict
+import contextlib
 import copy
 import hashlib
 import json
@@ -32,6 +33,13 @@ except ImportError:
     sys.exit('Error: could not import yaml (required to read meta.yaml '
              'files of conda recipes)')
 
+try:
+    loader = yaml.CLoader
+except:
+    loader = yaml.Loader
+
+from yaml.resolver import Resolver
+
 on_win = (sys.platform == 'win32')
 
 # arches that don't follow exact names in the subdir need to be mapped here
@@ -202,7 +210,9 @@ exception:
 
 def yamlize(data):
     try:
-        return yaml.load(data)
+        with stringify_numbers():
+            loaded_data = yaml.load(data, Loader=loader)
+        return loaded_data
     except yaml.error.YAMLError as e:
         if '{{' in data:
             try:
@@ -478,7 +488,8 @@ FIELDS = {
               'pin_depends', 'include_recipe',  # pin_depends is experimental still
               'preferred_env', 'preferred_env_executable_paths', 'run_exports',
               'ignore_run_exports', 'requires_features', 'provides_features',
-              'force_use_keys', "force_ignore_keys",
+              'force_use_keys', 'force_ignore_keys', 'merge_build_host',
+              'pre-link', 'post-link', 'pre-unlink',
               },
     'requirements': {'build', 'host', 'run', 'conflicts', 'run_constrained'},
     'app': {'entry', 'icon', 'summary', 'type', 'cli_opts',
@@ -786,6 +797,18 @@ def trim_build_only_deps(metadata, requirements_used):
     return requirements_used - to_remove
 
 
+@contextlib.contextmanager
+def stringify_numbers():
+    # ensure that numbers are not interpreted as ints or floats.  That trips up versions
+    #     with trailing zeros.
+    implicit_resolver_backup = Resolver.yaml_implicit_resolvers.copy()
+    for ch in list(u'-+0123456789'):
+        del Resolver.yaml_implicit_resolvers[ch]
+    yield
+    for ch in list(u'-+0123456789'):
+        Resolver.yaml_implicit_resolvers[ch] = implicit_resolver_backup[ch]
+
+
 class MetaData(object):
     def __init__(self, path, config=None, variant=None):
 
@@ -1049,6 +1072,9 @@ class MetaData(object):
             elif value.lower() in falses:
                 value = False
 
+        if value is None:
+            value = default
+
         return value
 
     def check_fields(self):
@@ -1064,9 +1090,9 @@ class MetaData(object):
                              (section, key))
         return True
 
-    def name(self):
-        res = self.get_value('package/name')
-        if not res:
+    def name(self, fail_ok=False):
+        res = self.meta.get('package', {}).get('name', '')
+        if not res and not fail_ok:
             sys.exit('Error: package/name missing in: %r' % self.meta_path)
         res = text_type(res)
         if res != res.lower():
@@ -1094,7 +1120,7 @@ class MetaData(object):
 
     def get_depends_top_and_out(self, typ):
         meta_requirements = ensure_list(self.get_value('requirements/' + typ, []))[:]
-        req_names = set(req.split()[0] for req in meta_requirements)
+        req_names = set(req.split()[0] for req in meta_requirements if req)
         extra_reqs = []
         if 'outputs' in self.meta:
             matching_output = [out for out in self.meta.get('outputs') if
@@ -1103,7 +1129,7 @@ class MetaData(object):
                 extra_reqs = utils.expand_reqs(
                     matching_output[0].get('requirements', [])).get(typ, [])
                 extra_reqs = [dep for dep in extra_reqs if dep.split()[0] not in req_names]
-        meta_requirements = list(set(meta_requirements) | set(extra_reqs))
+        meta_requirements = [req for req in (set(meta_requirements) | set(extra_reqs)) if req]
         return meta_requirements
 
     def ms_depends(self, typ='run'):
@@ -1118,6 +1144,8 @@ class MetaData(object):
                                   ])
         specs = OrderedDict()
         for spec in ensure_list(self.get_value('requirements/' + typ, [])):
+            if not spec:
+                continue
             try:
                 ms = MatchSpec(spec)
             except AssertionError:
@@ -1841,7 +1869,7 @@ class MetaData(object):
                                                              used_zip_key_groups)]
         for key in reduce_keys:
             values = full_collapsed_variants.get(key)
-            if values and not hasattr(values, 'keys'):
+            if values and not hasattr(values, 'keys') and key != 'zip_keys':
                 # save only one element from this key
                 reduced_collapsed_variants[key] = utils.ensure_list(next(iter(values)))
 
